@@ -7,31 +7,33 @@ use crate::{
     prelude::{Game, GameType},
 };
 
-pub fn read_all(file: &Path, launcher_path: &Path) -> Result<Vec<Game>> {
-    let conn = Connection::open_with_flags(&file, OpenFlags::SQLITE_OPEN_READ_ONLY)
-        .map_err(|error| {
+pub fn read_all(file: &Path, launcher_executable: &Path) -> Result<Vec<Game>> {
+    let conn =
+        Connection::open_with_flags(&file, OpenFlags::SQLITE_OPEN_READ_ONLY).map_err(|error| {
             Error::new(
                 ErrorKind::InvalidManifest,
                 format!("Invalid Amazon Games manifest: {}", error.to_string()),
             )
-        })
-        .unwrap();
+        })?;
 
-    let mut stmt = conn
-        .prepare("SELECT * FROM DbSet")
-        .map_err(|error| {
-            Error::new(
-                ErrorKind::InvalidManifest,
-                format!(
-                    "Error to read the Amazon Games manifest: {}",
-                    error.to_string()
-                ),
-            )
-        })
-        .unwrap();
+    let mut stmt = conn.prepare("SELECT * FROM DbSet").map_err(|error| {
+        Error::new(
+            ErrorKind::InvalidManifest,
+            format!(
+                "Error to read the Amazon Games manifest: {}",
+                error.to_string()
+            ),
+        )
+    })?;
+
+    let columns = stmt
+        .column_names()
+        .into_iter()
+        .map(String::from)
+        .collect::<Vec<String>>();
 
     let rows = stmt
-        .query_map([], |row| parse_row(row, launcher_path))
+        .query_map([], |row| parse_row(&columns, row, launcher_executable))
         .map_err(|error| match error {
             rusqlite::Error::QueryReturnedNoRows => Error::new(
                 ErrorKind::LibraryNotFound,
@@ -44,27 +46,25 @@ pub fn read_all(file: &Path, launcher_path: &Path) -> Result<Vec<Game>> {
                     error.to_string()
                 ),
             ),
-        })
-        .unwrap();
+        })?;
 
     let mut games = Vec::<Game>::new();
 
     for game in rows {
-        games.push(game.unwrap());
+        games.push(game?);
     }
 
     return Ok(games);
 }
 
-pub fn read(id: &str, file: &Path, launcher_path: &Path) -> Result<Game> {
-    let conn = Connection::open_with_flags(&file, OpenFlags::SQLITE_OPEN_READ_ONLY)
-        .map_err(|error| {
+pub fn read(id: &str, file: &Path, launcher_executable: &Path) -> Result<Game> {
+    let conn =
+        Connection::open_with_flags(&file, OpenFlags::SQLITE_OPEN_READ_ONLY).map_err(|error| {
             Error::new(
                 ErrorKind::InvalidManifest,
                 format!("Invalid Amazon Games manifest: {}", error.to_string()),
             )
-        })
-        .unwrap();
+        })?;
 
     let mut stmt = conn
         .prepare("SELECT * FROM DbSet WHERE Id = :id")
@@ -76,11 +76,18 @@ pub fn read(id: &str, file: &Path, launcher_path: &Path) -> Result<Game> {
                     error.to_string()
                 ),
             )
-        })
-        .unwrap();
+        })?;
+
+    let columns = stmt
+        .column_names()
+        .into_iter()
+        .map(String::from)
+        .collect::<Vec<String>>();
 
     return stmt
-        .query_row(&[(":id", id)], |row| parse_row(row, launcher_path))
+        .query_row(&[(":id", id)], |row| {
+            parse_row(&columns, row, launcher_executable)
+        })
         .map_err(|error| match error {
             rusqlite::Error::QueryReturnedNoRows => Error::new(
                 ErrorKind::GameNotFound,
@@ -96,26 +103,26 @@ pub fn read(id: &str, file: &Path, launcher_path: &Path) -> Result<Game> {
         });
 }
 
-fn parse_row(row: &Row, launcher_path: &Path) -> rusqlite::Result<Game> {
-    let columns = row.column_count();
-
+fn parse_row(
+    columns: &Vec<String>,
+    row: &Row,
+    launcher_executable: &Path,
+) -> rusqlite::Result<Game> {
     let mut game = Game::default();
     game._type = GameType::AmazonGames.to_string();
 
-    for col in 0..columns {
-        let name = row.column_name(col).unwrap();
+    for col in 0..columns.len() {
+        let name = columns.get(col).unwrap();
 
-        match name {
-            "Id" => game.id = row.get(col).unwrap(),
-            "ProductTitle" => game.name = row.get(col).unwrap(),
+        match name.as_str() {
+            "Id" => game.id = row.get(col)?,
+            "ProductTitle" => game.name = row.get(col)?,
             "InstallDirectory" => game.path = row.get::<_, String>(col).map(PathBuf::from).ok(),
-            "Installed" => game.state.installed = row.get(col).unwrap(),
+            "Installed" => game.state.installed = row.get(col)?,
             _ => {}
         }
     }
 
-    let launcher_executable = launcher_path.join("App").join("Amazon Games.exe");
-
     game.commands.launch = Some(vec![
         launcher_executable.display().to_string(),
         format!("amazon-games://play/{}", game.id),
