@@ -1,22 +1,53 @@
-use std::collections::HashMap;
-use std::path::{Path, PathBuf};
+use std::{
+    collections::HashMap,
+    path::{Path, PathBuf},
+};
 
 use serde::{Deserialize, Serialize};
 
-use crate::error::{Error, ErrorKind, Result};
-use crate::prelude::{Game, GameCommands, GameState, GameType};
-use crate::riotgames::types::RiotGamesProducts;
-use crate::util::path::fix_path_separator;
+use crate::{
+    error::{Error, ErrorKind, Result},
+    prelude::{Game, GameCommands, GameState, GameType},
+    utils::path::fix_path_separator,
+};
+
+use self::super::types::RiotGamesProducts;
 
 #[derive(Serialize, Deserialize, Debug)]
-struct ProductSettings {
-    product_install_full_path: String,
-    product_install_root: String,
+pub struct ProductSettings {
+    pub product_install_full_path: String,
+    pub product_install_root: String,
 }
 
 #[derive(Serialize, Deserialize, Debug)]
-struct RiotClientInstalls {
-    associated_client: Option<HashMap<String, String>>,
+pub struct RiotClientInstalls {
+    pub associated_client: Option<HashMap<String, String>>,
+    pub rc_default: String,
+    pub rc_live: String,
+}
+
+pub fn read_riot_client_installs(file: &Path) -> Result<RiotClientInstalls> {
+    let installs_file = std::fs::read_to_string(&file).map_err(|error| {
+        Error::new(
+            ErrorKind::InvalidManifest,
+            format!(
+                "Invalid Riot Games config: {} {}",
+                file.display().to_string(),
+                error.to_string()
+            ),
+        )
+    })?;
+
+    return serde_json::from_str::<RiotClientInstalls>(installs_file.as_str()).map_err(|error| {
+        Error::new(
+            ErrorKind::InvalidManifest,
+            format!(
+                "Invalid Riot Games config: {} {}",
+                file.display().to_string(),
+                error.to_string()
+            ),
+        )
+    });
 }
 
 pub fn read(file: &Path, launcher_path: &Path) -> Result<Game> {
@@ -29,13 +60,7 @@ pub fn read(file: &Path, launcher_path: &Path) -> Result<Game> {
                 error.to_string()
             ),
         )
-    });
-
-    if manifest_data.is_err() {
-        return Err(manifest_data.err().unwrap());
-    }
-
-    let manifest_data = manifest_data.unwrap();
+    })?;
 
     let product_settings =
         serde_yaml::from_str::<ProductSettings>(&manifest_data).map_err(|error| {
@@ -47,50 +72,7 @@ pub fn read(file: &Path, launcher_path: &Path) -> Result<Game> {
                     error.to_string()
                 ),
             )
-        });
-
-    if product_settings.is_err() {
-        return Err(product_settings.err().unwrap());
-    }
-
-    let product_settings = product_settings.unwrap();
-
-    let launcher_installs = launcher_path.join("RiotClientInstalls.json");
-
-    let installs_file = std::fs::read_to_string(&launcher_installs).map_err(|error| {
-        Error::new(
-            ErrorKind::InvalidManifest,
-            format!(
-                "Invalid Riot Games manifest: {} {}",
-                file.display().to_string(),
-                error.to_string()
-            ),
-        )
-    });
-
-    if installs_file.is_err() {
-        return Err(installs_file.err().unwrap());
-    }
-
-    let installs_file = installs_file.unwrap();
-
-    let riot_client_installs = serde_yaml::from_str::<RiotClientInstalls>(installs_file.as_str())
-        .map_err(|error| {
-            Error::new(
-                ErrorKind::InvalidManifest,
-                format!(
-                    "Invalid Riot Games manifest: {} {}",
-                    file.display().to_string(),
-                    error.to_string()
-                ),
-            )
-        });
-
-    if riot_client_installs.is_err() {
-        return Err(riot_client_installs.err().unwrap());
-    }
-
-    let riot_client_installs = riot_client_installs.unwrap();
+        })?;
 
     let manifest_filename = String::from(file.file_name().unwrap().to_str().unwrap())
         .replace(".product_settings.yaml", "");
@@ -103,9 +85,29 @@ pub fn read(file: &Path, launcher_path: &Path) -> Result<Game> {
         game_path.push_str("/");
     }
 
-    let launcher_executable = riot_client_installs
+    let launcher_client_installs = launcher_path.join("RiotClientInstalls.json");
+
+    let launcher_executable = read_riot_client_installs(&launcher_client_installs)?
         .associated_client
-        .and_then(|data| data.get(&game_path).cloned())
+        .and_then(|data| {
+            if cfg!(target_os = "windows") {
+                return data.get(&game_path).cloned();
+            }
+
+            if cfg!(target_os = "macos") {
+                let key = data
+                    .keys()
+                    .find(|path| path.starts_with(&game_path.to_string()));
+
+                if key.is_none() {
+                    return None;
+                }
+
+                return data.get(key.unwrap()).cloned();
+            }
+
+            return None;
+        })
         .map(PathBuf::from);
 
     if launcher_executable.is_none() {
@@ -121,13 +123,13 @@ pub fn read(file: &Path, launcher_path: &Path) -> Result<Game> {
 
     let mut game_install_path = PathBuf::from(&game_path);
 
-    if cfg!(windows) {
+    if cfg!(target_os = "windows") {
         game_install_path = fix_path_separator(&game_install_path);
     }
 
     let mut launcher_executable_path = launcher_executable.unwrap();
 
-    if cfg!(windows) {
+    if cfg!(target_os = "windows") {
         launcher_executable_path = fix_path_separator(&launcher_executable_path);
     }
 
